"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mesa_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from mesa_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
import pydantic
from pydantic import model_serializer
from typing import Any, Awaitable, Callable, Dict, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class GetByOrgByRepoCommitsRequestTypedDict(TypedDict):
    org: str
    repo: str
    cursor: NotRequired[str]
    limit: NotRequired[int]
    ref: NotRequired[str]


class GetByOrgByRepoCommitsRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    repo: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    cursor: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    ref: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["cursor", "limit", "ref"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsAuthorTypedDict(TypedDict):
    name: str
    email: str
    date_: NotRequired[str]


class GetByOrgByRepoCommitsAuthor(BaseModel):
    name: str

    email: str

    date_: Annotated[Optional[str], pydantic.Field(alias="date")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["date"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsCommitterTypedDict(TypedDict):
    name: str
    email: str
    date_: NotRequired[str]


class GetByOrgByRepoCommitsCommitter(BaseModel):
    name: str

    email: str

    date_: Annotated[Optional[str], pydantic.Field(alias="date")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["date"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class CommitTypedDict(TypedDict):
    sha: str
    message: str
    author: GetByOrgByRepoCommitsAuthorTypedDict
    committer: GetByOrgByRepoCommitsCommitterTypedDict


class Commit(BaseModel):
    sha: str

    message: str

    author: GetByOrgByRepoCommitsAuthor

    committer: GetByOrgByRepoCommitsCommitter


class GetByOrgByRepoCommitsResponseBodyTypedDict(TypedDict):
    r"""Commit list"""

    next_cursor: Nullable[str]
    has_more: bool
    commits: List[CommitTypedDict]


class GetByOrgByRepoCommitsResponseBody(BaseModel):
    r"""Commit list"""

    next_cursor: Nullable[str]

    has_more: bool

    commits: List[Commit]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetByOrgByRepoCommitsResponseTypedDict(TypedDict):
    result: GetByOrgByRepoCommitsResponseBodyTypedDict


class GetByOrgByRepoCommitsResponse(BaseModel):
    next: Union[
        Callable[[], Optional[GetByOrgByRepoCommitsResponse]],
        Callable[[], Awaitable[Optional[GetByOrgByRepoCommitsResponse]]],
    ]

    result: GetByOrgByRepoCommitsResponseBody



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import getbyorgapikeysop as models_getbyorgapikeysop
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgAPIKeysInternalServerErrorData(BaseModel):
    error: models_getbyorgapikeysop.GetByOrgAPIKeysInternalServerErrorError


@dataclass(unsafe_hash=True)
class GetByOrgAPIKeysInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgAPIKeysInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgAPIKeysInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgAPIKeysConflictErrorData(BaseModel):
    error: models_getbyorgapikeysop.GetByOrgAPIKeysConflictError


@dataclass(unsafe_hash=True)
class GetByOrgAPIKeysConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgAPIKeysConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgAPIKeysConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgAPIKeysNotAcceptableErrorData(BaseModel):
    error: models_getbyorgapikeysop.GetByOrgAPIKeysNotAcceptableError


@dataclass(unsafe_hash=True)
class GetByOrgAPIKeysNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgAPIKeysNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgAPIKeysNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgAPIKeysNotFoundErrorData(BaseModel):
    error: models_getbyorgapikeysop.GetByOrgAPIKeysNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgAPIKeysNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgAPIKeysNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgAPIKeysNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgAPIKeysForbiddenErrorData(BaseModel):
    error: models_getbyorgapikeysop.GetByOrgAPIKeysForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgAPIKeysForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgAPIKeysForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgAPIKeysForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgAPIKeysUnauthorizedErrorData(BaseModel):
    error: models_getbyorgapikeysop.GetByOrgAPIKeysUnauthorizedError


@dataclass(unsafe_hash=True)
class GetByOrgAPIKeysUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgAPIKeysUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgAPIKeysUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgAPIKeysBadRequestErrorData(BaseModel):
    error: models_getbyorgapikeysop.GetByOrgAPIKeysBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgAPIKeysBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgAPIKeysBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgAPIKeysBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import (
    getbyorgbyrepoanalyticsop as models_getbyorgbyrepoanalyticsop,
)
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgByRepoAnalyticsInternalServerErrorData(BaseModel):
    error: (
        models_getbyorgbyrepoanalyticsop.GetByOrgByRepoAnalyticsInternalServerErrorError
    )


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAnalyticsInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgByRepoAnalyticsInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAnalyticsInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoAnalyticsConflictErrorData(BaseModel):
    error: models_getbyorgbyrepoanalyticsop.GetByOrgByRepoAnalyticsConflictError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAnalyticsConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgByRepoAnalyticsConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAnalyticsConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoAnalyticsNotAcceptableErrorData(BaseModel):
    error: models_getbyorgbyrepoanalyticsop.GetByOrgByRepoAnalyticsNotAcceptableError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAnalyticsNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgByRepoAnalyticsNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAnalyticsNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoAnalyticsNotFoundErrorData(BaseModel):
    error: models_getbyorgbyrepoanalyticsop.GetByOrgByRepoAnalyticsNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAnalyticsNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgByRepoAnalyticsNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAnalyticsNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoAnalyticsForbiddenErrorData(BaseModel):
    error: models_getbyorgbyrepoanalyticsop.GetByOrgByRepoAnalyticsForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAnalyticsForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgByRepoAnalyticsForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAnalyticsForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoAnalyticsUnauthorizedErrorData(BaseModel):
    error: models_getbyorgbyrepoanalyticsop.GetByOrgByRepoAnalyticsUnauthorizedError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAnalyticsUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgByRepoAnalyticsUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAnalyticsUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoAnalyticsBadRequestErrorData(BaseModel):
    error: models_getbyorgbyrepoanalyticsop.GetByOrgByRepoAnalyticsBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoAnalyticsBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgByRepoAnalyticsBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoAnalyticsBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
